Learn R Programming

ciftiTools (version 0.21.1)

check_render_backend: Verify the rgl rendering backend has what it needs. Required deps depend on the path that will run: native -> rgl HTML widget fallback -> rgl + htmlwidgets web PNG (Tahoe etc) -> rgl + webshot2 + htmlwidgets + Chrome

Description

Verify the rgl rendering backend has what it needs. Required deps depend on the path that will run: native -> rgl HTML widget fallback -> rgl + htmlwidgets web PNG (Tahoe etc) -> rgl + webshot2 + htmlwidgets + Chrome

Usage

check_render_backend(fname = FALSE)

Arguments

fname

As passed to the view function.