Description Usage Arguments Value Functions See Also
View source: R/convert_xifti.R
Convert the intent of a CIFTI file or "xifti" object
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 | convert_to_dlabel(
x,
cifti_target_fname = NULL,
values = NULL,
nsig = Inf,
colors = "Set2",
add_white = TRUE,
return_conversion_table = FALSE
)
convert_to_dscalar(x, cifti_target_fname = NULL, names = NULL)
convert_to_dtseries(
x,
cifti_target_fname = NULL,
time_start = 0,
time_step = 1,
time_unit = c("second", "hertz", "meter", "radian")
)
convert_xifti(
x,
to = c("dscalar", "dtseries", "dlabel"),
cifti_target_fname = NULL,
...
)
|
x |
The CIFTI file name or |
cifti_target_fname |
File name for the converted CIFTI. Only used if
|
values |
(Optional) A vector of the original data values. They should all
be unique. They may not all occur in the |
nsig |
Take this many significant digits for the data values. If
|
colors |
(Optional) "ROY_BIG_BL", the name of a ColorBrewer palette
(see |
add_white |
Append white to the beginning of the colors? Default: |
return_conversion_table |
Return the conversion table along with the
converted |
names |
The column names. If |
time_start, time_step, time_unit |
(Optional) metadata for the new dtseries |
to |
The desired intent: |
... |
Only used if |
If x is a CIFTI, the target is a "dlabel" and
return_conversion_table, a length-2 list with the first entry being
the ".dlabel" "xifti" and the second being the conversion table.
Otherwise, the "xifti" or the output CIFTI file name is directly
returned.
convert_to_dlabel: Give the ".dlabel" intent (code 3007/ConnDenseLabel) to an input
"xifti". Will use the same label table for each data column.
convert_to_dscalar: Give the ".dscalar" intent (code 3006/ConnDenseScalar) to an input
CIFTI file or "xifti" object.
convert_to_dtseries: Give the ".dtseries" intent (code 3002/ConnDenseSeries) to an input
"xifti" object.
Other functions for manipulating 'xifti' objects:
add_surf(),
apply_xifti(),
combine_xifti(),
merge_xifti(),
newdata_xifti(),
remove_xifti(),
select_xifti(),
transform_xifti()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.