Description Usage Arguments Value See Also
Remove a brain structure or surface from a "xifti"
1 | remove_xifti(xifti, remove = NULL)
|
xifti |
A |
remove |
A character vector containing one or more of the following:
|
The new "xifti" with the requested component(s) removed
Other functions for manipulating 'xifti' objects:
add_surf(),
apply_xifti(),
combine_xifti(),
convert_to_dlabel(),
merge_xifti(),
newdata_xifti(),
select_xifti(),
transform_xifti()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.