resamp_fnames
Where to write the resampled files. This is a named list where each entry's name is a file type label, and each entry's value is a file name indicating where to write the corresponding resampled file. The recognized file type labels are: "cortexL", "cortexR", "ROIcortexL", "ROIcortexR", "validROIcortexL", and "validROIcortexR".
Entry values can be NULL, in which case a default file name will be
used: see resample_cifti_default_fname. Default file names
will also be used for files that need to be resampled/written but without a
corresponding entry in resamp_fnames.
Entries in resamp_fnames will be ignored if they are not needed
based on [ROI_]brainstructures. For example, if
brainstructures="left", then resamp_fnames$cortexR will be
ignored if specified.
The write_dir argument can be used to place each resampled file in
the same directory.