sep_fnames
(Optional) Where to write the separated files (override their default file names). This is a named list where each entry's name is a file type label, and each entry's value is a file name indicating where to write the corresponding separated file. The recognized file type labels are: "cortexL", "cortexR", "ROIcortexL", "ROIcortexR", "subcortVol", and "subcortLabs".
Entry values can be NULL, in which case a default file name will be
used: see cifti_component_suffix. Default file names
will also be used for files that need to be separated/written but without a
corresponding entry in sep_fnames.
Entries in sep_fnames will be ignored if they are not needed
based on [ROI_]brainstructures. For example, if
brainstructures="left", then sep_fnames$cortexR will be
ignored if specified.
The write_dir argument can be used to place each separated file in
the same directory.