Description Usage Arguments Details Value Connectome Workbench See Also
View source: R/separate_cifti.R
Separate a CIFTI file into GIFTI files for the cortical data and NIFTI files
for the subcortical data and labels. ROIs can also be written to indicate
the medial wall mask (cortex) and volume mask (subcortex). This uses the
Connectome Workbench command -cifti-separate.
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 | separate_cifti(
cifti_fname,
brainstructures = c("left", "right"),
cortexL_fname = NULL,
cortexR_fname = NULL,
subcortVol_fname = NULL,
subcortLabs_fname = NULL,
ROI_brainstructures = "all",
ROIcortexL_fname = NULL,
ROIcortexR_fname = NULL,
ROIsubcortVol_fname = NULL,
write_dir = NULL
)
separateCIfTI(
cifti_fname,
brainstructures = c("left", "right"),
cortexL_fname = NULL,
cortexR_fname = NULL,
subcortVol_fname = NULL,
subcortLabs_fname = NULL,
ROI_brainstructures = "all",
ROIcortexL_fname = NULL,
ROIcortexR_fname = NULL,
ROIsubcortVol_fname = NULL,
write_dir = NULL
)
separatecii(
cifti_fname,
brainstructures = c("left", "right"),
cortexL_fname = NULL,
cortexR_fname = NULL,
subcortVol_fname = NULL,
subcortLabs_fname = NULL,
ROI_brainstructures = "all",
ROIcortexL_fname = NULL,
ROIcortexR_fname = NULL,
ROIsubcortVol_fname = NULL,
write_dir = NULL
)
|
cifti_fname |
File path to a CIFTI file (ending in ".d*.nii"). |
brainstructures |
Character vector indicating which brain structure(s)
to obtain: If a brain structure is indicated but does not exist in the CIFTI file, a warning will occur and that brain structure will be skipped. |
cortexL_fname, cortexR_fname |
(Optional) GIFTI file names
(*.[func/label].gii) to save the [left/right] cortex data to. If not provided,
defaults to dtseries and dscalar files should use "func", whereas dlabel files should use "label". |
subcortVol_fname, subcortLabs_fname |
(Optional) NIFTI file names to save
the subcortical [volume/labels] to. If not provided, defaults to
|
ROI_brainstructures |
Which ROIs should be obtained? |
ROIcortexL_fname, ROIcortexR_fname |
(Optional) GIFTI file names
(*.[func/label].gii) to save the [left/right] cortex ROI to. If not provided,
defaults to dtseries and dscalar files should use "func", whereas dlabel files should use "label". |
ROIsubcortVol_fname |
(Optional) NIFTI file names to save
the subcortical ROI to. If not provided, defaults to
|
write_dir |
Where should the separated files be placed?
|
Time unit, start, and step (dtseries files) will not be written to the GIFTI/NIFTIs. Column names (dscalar files) will not be written to the GIFTIs, as well as label names and colors (dlabel files). (Haven't checked the NIFTIs yet.)
ROI/medial wall behavior: If there are 32k vertices in the left cortex with
3k representing the medial wall, then both cortexL_fname and
ROIcortexL_fname will have 32k entries, 3k of which having a value of
0 indicating the medial wall. The non-medial wall entries will have the
data values in cortexL_fname and a value of 1 in
ROIcortexL_fname. Thus, exporting ROIcortexL_fname is vital if
the data values include 0, because 0-valued non-medial wall vertices and
medial wall vertices cannot be distinguished from one another within
cortexL_fname alone.
A named character vector with the file paths to the written NIFTI and GIFTI files
This function interfaces with the "-cifti-separate" Workbench command.
Other functions for writing CIFTI or GIFTI data:
write_cifti(),
write_metric_gifti(),
write_subcort_nifti(),
write_surf_gifti()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.