write_cifti_from_separate: Write a CIFTI file from NIFTI and GIFTI files

Description Usage Arguments Details

View source: R/write_cifti_from_separate.R

Description

Make a CIFTI file from component NIFTI/GIFTI files using the -cifti-create-... Connectome Workbench commands.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
write_cifti_from_separate(
  cifti_fname,
  cortexL_fname = NULL,
  ROIcortexL_fname = NULL,
  cortexR_fname = NULL,
  ROIcortexR_fname = NULL,
  subcortVol_fname = NULL,
  subcortLabs_fname = NULL,
  timestep = NULL,
  timestart = NULL
)

Arguments

cifti_fname

Path to the CIFTI to write.

cortexL_fname

The left cortex file.

ROIcortexL_fname

The left cortex ROI file.

cortexR_fname

The right cortex file.

ROIcortexR_fname

The right cortex ROI file.

subcortVol_fname

The subcortical data file.

subcortLabs_fname

The subcortical labels file.

timestep

If a dense time series ("dtseries.nii") file is being written, this is the time between measurements. If NULL, use the Connectome Workbench default (1.0).

timestart

If a dense time series ("dtseries.nii") file is being written, this is starting time. If NULL, use the Connectome Workbench default (0.0).

Details

Every provided component will be included. The ROIs are only used if the corresponding cortex is provided. Either both or none of the subcortical NIFTIs should be provided.


neuroconductor/ciftiTools documentation built on Dec. 22, 2021, 1:09 a.m.