Description Usage Arguments Details Value Connectome Workbench See Also
Write subcortical data to NIFTI files representing the data values,
subcortical structure labels, and volumetric mask. The input formats of
subcortVol, subcortLabs, and subcortMask
correspond to the data structures of xifti$data$subcort,
xifti$meta$subcort$labels , and xifti$meta$subcort$mask
respectively. subcortVol and subcortLabs should be vectorized,
so if they are volumes consider using RNifti::writeNIfTI.
1 2 3 4 5 6 7 8 9 10 | write_subcort_nifti(
subcortVol,
subcortLabs,
subcortMask,
trans_mat = NULL,
subcortVol_fname,
subcortLabs_fname,
ROIsubcortVol_fname = NULL,
fill = 0
)
|
subcortVol |
A vectorized data matrix: V voxels by T measurements |
subcortLabs |
Numeric (0 and 3-21) or factor vector corresponding to
subcortical structure labels. See |
subcortMask |
Logical volumetric mask. Values of 0 represent out-of-mask voxels (not subcortical), and values of 1 represent in-mask voxels (subcortical), |
trans_mat |
The TransformationMatrixIJKtoXYZ, or equivalently the desired
sform matrix (srow_x, srow_y and srow_z) to write. If |
subcortVol_fname, subcortLabs_fname, ROIsubcortVol_fname |
File path to
a NIFTI to save the corresponding data. |
fill |
Values to use for out-of-mask voxels. Default: |
All file path arguments are required except ROIsubcortVol_fname. If
not provided, the volumetric mask will not be written. (It's redundant with
the 0 values in subcortLabs_fname because valid labels have positive
indexes.)
Named character vector with the "subcortVol",
"subcortLabs", and "ROIsubcortVol" file names (if written)
This function interfaces with the "-volume-label-import" Workbench
Command.
Other functions for writing CIFTI or GIFTI data:
separate_cifti(),
write_cifti(),
write_metric_gifti(),
write_surf_gifti()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.