Verify the rgl rendering backend has what it needs. Required deps depend on the path that will run: native -> rgl HTML widget fallback -> rgl + htmlwidgets web PNG (Tahoe etc) -> rgl + webshot2 + htmlwidgets + Chrome
check_render_backend(fname = FALSE)As passed to the view function.